## Additional documentation

* [Overview diagram](Documentation/VPNTracker365.png)
* [Tracker Connection Storage Format](https://vcs.muc.equinux.net/equinux/vpnthq/-/blob/develop/doc/OldTrackerConnectionFormat/TarckerConnectionFormat.md)
* [License Failure](Documentation/License_Failure/License_Failure.md)
* [Details about the System Extension](Documentation/SystemExtension.md)
* [Debugging notes](Documentation/Debugging.md)
* [Protocol documentations](Documentation/Protocols.md)
* [Notes about the iOS app](Documentation/iOSNotes.md)
* [Notes about Connection Safe and Team Safe](Documentation/SafeSync.md)
* [`vpntracker` URL scheme](Documentation/VPNTrackerURLs.md)
* [Capabilities per version](Documentation/versioncapabilities.md)
* [Adding a new World Connect Country or City](Documentation/WoC.md)
* [`netstat -r` flags](Documentation/Netstat_Flags.md)
* [Things to test with each major macOS version](Documentation/Testing.md)
* [iOS Licensing Overivew](Documentation/iOSLicenses.md)
* [Test Device Setup](Documentation/Test%20Device%20Setup/Overview.md)
* [MDM/Configuration Profiles support](Documentation/SettingsManaged.md)
  * [Notes for Microsoft Endpoint Manager/Intune](Documentation/SettingsManaged-MS.md)


## Version handling (Beta, Nightly)

In order to correctly mark versions as release, beta, or nightly, please make sure to mark
versions released via eqWeb/eqStore so that the build versions follow this order:

```
Release < Beta < Nightly
```

If this order is not maintained, a version may incorrectly get flagged a belonging to a
"higher" level.

A user may chose to explicitly subscribe to beta or nightly updates in the preferences.
If they did not and the current version is detected to be a beta or nightly, VPN Tracker
tries to fetch updates of the corresponding level until the next regular release version.


## Branching

This repository is following the [Git Flow](https://www.atlassian.com/git/tutorials/comparing-workflows/gitflow-workflow) branching model.

To support automatic Git Flow behavior on command line and within UI tools, you need to configure Git Flow after cloning the repository. You can either run `git flow init` and answer the questions or you can just copy and paste the config below to your `.git/config` file (faster and avoids typos):

```
[gitflow "branch"]
	master = Main
	develop = Development

[gitflow "prefix"]
	feature = Features/
	bugfix = Bugfixes/
	release = Releases/
	hotfix = Hotfixes/
	support = Support/
	versiontag = Releases/<Major>.x/

[gitflow "path"]
	hooks = .git/hooks
```

Where `<Major>` is the major release version (e.g. 21) and needs to be updated whenever we increase the major release version.

To install Git Flow support for the shell, install [MacPorts](https://www.macports.org/install.php) and use `sudo port install git-flow` (recommend). You can also install it via Brew but Brew is insecure (root exploits) and thus not recommend.

Or use a free Git UI client, like [Sourcetree](https://www.sourcetreeapp.com) (`Repository > Git flow/Hg flow`) Note: You can also copy the pre-build Git Flow binary from the Sourcetree app bundle, it's located in `Sourcetree.app/Contents/Resources/git_local/gitflow` and use this for your terminal operations.


## Developer Troubleshooting

If the system extensions can't be loaded in a debug build, try running

```systemextensionsctl developer on```

 in the terminal.


## Log PLI Tips

For Log PLI strings you can use markdown-style URLs to link to specific app settings.
Here are some examples:

```
Basic settings

[[vpntracker:///goto?tab=Settings&id=vpnGatewayAddress][VPN gateway's hostname]]
[[vpntracker:///goto?tab=Settings&id=localNetworks][local address or network]]
[[vpntracker:///goto?tab=Settings&id=remoteNetworks][remote network(s)]]
[[vpntracker:///goto?tab=Settings&id=remoteNetworksReplicationContainer][Remote Network(s)]]
[[vpntracker:///psk-dialog][enter the pre-shared key again]]
[[vpntracker:///goto?tab=Settings&id=identifiersStripe][identifier settings]]

Advanced settings
[[vpntracker:///goto?tab=Advanced&id=timerConnectTimeout][timeout value]]
[[vpntracker:///goto?tab=Advanced&id=phase1DHGroups][Diffie-Hellman group]]
[[vpntracker:///goto?tab=Advanced&id=phase1LifetimeInSeconds][phase 1]]
[[vpntracker:///goto?tab=Advanced&id=phase2LifetimeInSeconds][phase 2]]
[[vpntracker:///goto?tab=Advanced&id=timerConnectTimeout][connection timeout]]
[[vpntracker:///goto?tab=Advanced&id=phase2Stripe][proposals]]

```
Note: For `goto?` links you can add `&error` to the end to highlight the referenced field in red (error), instead of yellow e.g.:
`vpntracker:///goto?tab=Settings&id=vpnGatewayAddress&error`

```
Other
[[vpntracker:///create-tsr][send a Technical Support Report]]
[[vpntracker:///manual][VPN Tracker Manual]]
[[vpntracker:///start][restart the connection]]
```
Use
```
[[NEW]]
```
for linebreaks.
